{% load helpers %}
{% load i18n %}


<div class="card">

  <h5 class="card-header">{% trans "Classification" %}</h5>
  <table class="table table-hover attr-table">

    {% include 'sop_infra/tools/display_detail.html' with name="site_infra_sysinfra" %}
    {% include 'sop_infra/tools/display_detail.html' with name="site_type_indus" %}
    {% include 'sop_infra/tools/display_detail.html' with name="criticity_stars" %}
    {% include 'sop_infra/tools/display_detail.html' with name="site_phone_critical" badge=1 %}
    {% include 'sop_infra/tools/display_detail.html' with name="site_type_red" badge=1 %}
    {% include 'sop_infra/tools/display_detail.html' with name="site_type_vip" badge=1 %}
    {% include 'sop_infra/tools/display_detail.html' with name="site_type_wms" badge=1 %}

</table>

</div>

