{% load helpers %}
{% load i18n %}

<div class="card">

  <h5 class="card-header">{% trans "Sizing" %}</h5>
  <table class="table table-hover attr-table">

    {% include 'sop_infra/tools/display_detail.html' with name="ad_direct_users" %}
    {% include 'sop_infra/tools/display_detail.html' with name="est_cumulative_users" %}
    {% include 'sop_infra/tools/display_detail.html' with name="wan_computed_users" %}
    {% include 'sop_infra/tools/display_detail.html' with name="site_user_count" %}
    {% include 'sop_infra/tools/display_detail.html' with name="site_mx_model" %}
    {% include 'sop_infra/tools/display_detail.html' with name="wan_reco_bw" %}

  </table>

</div>

