# Generated by Django 5.0.9 on 2024-10-23 08:27

import django.db.models.deletion
import taggit.managers
import utilities.json
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('dcim', '0190_nested_modules'),
        ('extras', '0121_customfield_related_object_filter'),
    ]

    operations = [
        migrations.CreateModel(
            name='SopInfra',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True, null=True)),
                ('last_updated', models.DateTimeField(auto_now=True, null=True)),
                ('custom_field_data', models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder)),
                ('site_infra_sysinfra', models.CharField(blank=True, null=True)),
                ('site_type_industrial', models.CharField(blank=True, null=True)),
                ('site_phone_critical', models.CharField(blank=True, null=True)),
                ('site_type_red', models.CharField(blank=True, null=True)),
                ('site_type_vip', models.CharField(blank=True, null=True)),
                ('site_type_wms', models.CharField(blank=True, null=True)),
                ('ad_cumul_user', models.PositiveBigIntegerField(blank=True, null=True)),
                ('est_cumulative_users', models.PositiveBigIntegerField(blank=True, null=True)),
                ('wan_reco_bw', models.PositiveBigIntegerField(blank=True, null=True)),
                ('wan_computed_users', models.PositiveBigIntegerField(blank=True, null=True)),
                ('swanha', models.CharField(blank=True, null=True)),
                ('hub_order_setting', models.CharField(blank=True, null=True)),
                ('hub_default_route_setting', models.CharField(blank=True, null=True)),
                ('sdwan1_bw', models.CharField(blank=True, null=True)),
                ('sdwan2_bw', models.CharField(blank=True, null=True)),
                ('migration_sdwan', models.CharField(blank=True, null=True)),
                ('monitor_in_starting', models.CharField(blank=True, null=True)),
                ('site', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='dcim.site')),
                ('site_sdwan_master_location', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='dcim.location')),
                ('tags', taggit.managers.TaggableManager(through='extras.TaggedItem', to='extras.Tag')),
            ],
            options={
                'verbose_name': 'Infrastructure',
                'verbose_name_plural': 'Infrastructures',
                'abstract': False,
            },
        ),
        migrations.AddConstraint(
            model_name='sopinfra',
            constraint=models.UniqueConstraint(fields=('site',), name='sop_infra_sopinfra_unique_site', violation_error_message='This site has already an Infrastrcture.'),
        ),
    ]
