# Generated by Django 5.0.9 on 2024-11-05 12:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sop_infra', '0008_alter_sopinfra_site_mx_model'),
    ]

    operations = [
        migrations.AddField(
            model_name='sopinfra',
            name='ad_direct_users',
            field=models.PositiveBigIntegerField(blank=True, null=True),
        ),
    ]
