{% load helpers %}
{% load perms %}
{% load i18n %}

<div class="card">

  <h2 class="card-header"> {% trans "Sizing" %}

    <div class="card-actions">
      {% if not object.id and request.user|can_add:object %}
      <a href="{% url 'plugins:sop_infra:sizing_add' pk=site.id %}" class="btn btn-ghost-primary btn-sm">
        <i class="mdi mdi-plus-thick" aria-hidden="true"></i>Add Sizing
      </a>
      {% elif object.id and request.user|can_change:object %}
      <a href="{% url 'plugins:sop_infra:sizing_edit' pk=object.id %}" class="btn btn-ghost-primary btn-sm">
        <i class="mdi mdi-pencil" aria-hidden="true"></i>Edit Sizing
      </a>
      {% endif %}
    </div>

  </h2>

  {% if request.user|can_view:object %}
  <table class="table table-hover attr-table">

    <ul class="list-group list-group-flush">

      {% include 'sop_infra/tools/display.html' with name="ad_direct_users" %}
      {% include 'sop_infra/tools/display.html' with name="est_cumulative_users" %}
      {% include 'sop_infra/tools/display.html' with name="wan_computed_users" %}
      {% include 'sop_infra/tools/display.html' with name="site_user_count" %}
      {% include 'sop_infra/tools/display.html' with name="site_mx_model" %}
      {% include 'sop_infra/tools/display.html' with name="wan_reco_bw" %}

    </ul>

  </table>
  {% endif %}

</div>

