# Generated by Django 5.0.9 on 2024-11-18 13:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sop_infra', '0009_sopinfra_ad_direct_users'),
    ]

    operations = [
        migrations.RenameField(
            model_name='sopinfra',
            old_name='ad_cumul_user',
            new_name='ad_cumulative_users',
        ),
    ]
