# Generated by Django 5.0.9 on 2024-11-20 09:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sop_infra', '0010_rename_ad_cumul_user_sopinfra_ad_cumulative_users'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='sopinfra',
            name='ad_cumulative_users',
        ),
    ]
