# Generated by Django 5.0.9 on 2024-10-29 10:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dcim', '0190_nested_modules'),
        ('extras', '0121_customfield_related_object_filter'),
        ('sop_infra', '0005_sopinfra_site_user_count'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='sopinfra',
            constraint=models.CheckConstraint(check=models.Q(('site', models.F('master_site')), _negated=True), name='sop_infra_sopinfra_master_site_equal_site', violation_error_message='SDWAN MASTER site cannot be itself'),
        ),
    ]
