# Generated by Django 5.0.9 on 2024-11-05 09:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sop_infra', '0007_sopinfra_criticity_stars_sopinfra_site_mx_model'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sopinfra',
            name='site_mx_model',
            field=models.CharField(blank=True, max_length=6, null=True),
        ),
    ]
