# Generated by Django 5.0.9 on 2024-10-24 14:15

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dcim', '0190_nested_modules'),
        ('sop_infra', '0003_rename_swanha_sopinfra_sdwanha'),
    ]

    operations = [
        migrations.AddField(
            model_name='sopinfra',
            name='master_site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='master_site', to='dcim.site'),
        ),
    ]
