# Generated by Django 5.0.9 on 2024-10-23 11:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sop_infra', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='sopinfra',
            old_name='site_type_industrial',
            new_name='site_type_indus',
        ),
    ]
