{% load helpers %}
{% load mptt %}

{% if object == "False" %}
  <i class="mdi mdi-close-thick text-danger" title="False"></i>
{% elif object == "True" %}
    <i class="mdi mdi-check-bold text-success" title="True"></i>
{% else %}
    <span>&mdash;</span>
{% endif %}

